@@ -189,15 +189,12 @@ class Akinator:
 
         Parameters
         ----------
-        language: :class:`str` | :class:`None`
-            The language to use when starting the game.
+        language: :class:`Language` | :class:`None`
+            The language to use when starting the game. If :class:`None`, the language specified in the constructor will be used.
+        theme: :class:`Theme` | :class:`None`
+            The theme to use when starting the game. If :class:`None`, the theme specified in the constructor will be used.
         child_mode: :class:`bool`
-            Whether or not to use child mode. If True, the game will be more "child-friendly".
-
-        Raises
-        ------
-        :exc:`TypeError`
-            The `session` parameter was not a :class:`aiohttp.ClientSession`.
+            Whether or not to use child mode. If True, the game will be more "child-friendly". If :class:`None`, the child mode specified in the constructor will be used.
 
         Returns
         -------
@@ -250,18 +247,17 @@ class Akinator:
 
         Parameter
         ---------
-        answer: :class:`str`
-            The answer to the current question. It can be one of the following:
-                - Yes: "y", "yes" "0"
-                - No: "n", "no", "1"
-                - I don't know: "i", "idk", "i dont know", "i don't know", "2"
-                - Probably: "p", "probably", "3"
-                - Probably not: "pn", "probably not", "4"
+        answer: :class:`Answer`
+            The answer to the current question.
+
+            .. note::
+
+                Calling this method with :attr:`Answer.back` will call :meth:`Akinator.back` for you.
 
         Raises
         ------
-        :exc:`InvalidAnswerError`
-            The answer was not one of the valid answers.
+        :exc:`NoMoreQuestions`
+            There are no more questions to be asked. Call :meth:`Akinator.win` to get the results.
 
         Returns
         -------
@@ -269,6 +265,9 @@ class Akinator:
             The next question that Akinator asks.
         """
 
+        if answer == Answer.BACK:
+            return await self.back()
+
         async with self._session.get(
             ANSWER_URL.format(
                 self.uri,
@@ -296,6 +295,11 @@ class Akinator:
         """
         Go back to the previous question.
 
+        .. note::
+
+            :meth:`Akinator.answer` will call this method for you if you pass in :attr:`Answer.BACK`.
+            It is recommended that you use that for better experience.
+
         Raises
         ------
         :exc:`CantGoBackAnyFurther`
